**Example 1: xx**

xx

Input: 

```
tccli dsgc ModifyDSPAESTaskResult --cli-unfold-argument  \
    --DspaId abc \
    --FieldResultId 0 \
    --IsSetNonSensitiveField True \
    --DestRuleId 0 \
    --DestCategoryId 0 \
    --DestLevelId 0 \
    --ComplianceId 0
```

Output: 
```
{
    "Response": {
        "RequestId": "abc"
    }
}
```

